summary refs log tree commit diff
path: root/nixos/modules/config
diff options
context:
space:
mode:
authornikstur <nikstur@outlook.com>2023-10-20 15:43:27 +0200
committernikstur <nikstur@outlook.com>2023-10-26 01:51:07 +0200
commitb5617e0575c36b16779e2948518d0fc299198ebb (patch)
tree31abbc9065871a85736ab9fa76d9f2285288255d /nixos/modules/config
parent47ff8d20d752b95befaa2ebb3f6bae4d3eb37a18 (diff)
downloadnixpkgs-b5617e0575c36b16779e2948518d0fc299198ebb.tar
nixpkgs-b5617e0575c36b16779e2948518d0fc299198ebb.tar.gz
nixpkgs-b5617e0575c36b16779e2948518d0fc299198ebb.tar.bz2
nixpkgs-b5617e0575c36b16779e2948518d0fc299198ebb.tar.lz
nixpkgs-b5617e0575c36b16779e2948518d0fc299198ebb.tar.xz
nixpkgs-b5617e0575c36b16779e2948518d0fc299198ebb.tar.zst
nixpkgs-b5617e0575c36b16779e2948518d0fc299198ebb.zip
nixos/mysql: replace activationScripts via preStart
Diffstat (limited to 'nixos/modules/config')
-rw-r--r--nixos/modules/config/mysql.nix4
1 files changed, 2 insertions, 2 deletions
diff --git a/nixos/modules/config/mysql.nix b/nixos/modules/config/mysql.nix
index 2f13c56f2ae..95c9ba76663 100644
--- a/nixos/modules/config/mysql.nix
+++ b/nixos/modules/config/mysql.nix
@@ -429,11 +429,11 @@ in
       '';
     };
 
     # Activation script to append the password from the password file
     # to the configuration files. It also fixes the owner of the
     # libnss-mysql-root.cfg because it is changed to root after the
     # password is appended.
-    system.activationScripts.mysql-auth-passwords = ''
+    systemd.services.mysql.preStart = ''
       if [[ -r ${cfg.passwordFile} ]]; then
         org_umask=$(umask)
         umask 0077
@@ -429,11 +429,11 @@ in
     };
 
-    # Activation script to append the password from the password file
+    # preStart script to append the password from the password file
     # to the configuration files. It also fixes the owner of the
     # libnss-mysql-root.cfg because it is changed to root after the